.. _faqs:

FAQS
====

Contributing to PyCLibrary
--------------------------

You can contribute in different ways:

Report issues
^^^^^^^^^^^^^

You can report any issues with the package, the documentation to the PyCLibrary
`issue tracker`_. Also feel free to submit feature requests, comments or 
questions.


Contribute code
^^^^^^^^^^^^^^^

To contribute fixes, code or documentation to PyCLibrary, fork PyCLibrary in 
github_ and submit the changes using a pull request.

In any case, feel free to use the `issue tracker`_ to discuss ideas for new 
features or improvements.

.. _github: http://github.com/MatthieuDartiailh/pyclibrary
.. _`issue tracker`: https://github.com/MatthieuDartiailh/pyclibrary/issues




